@@ -29,6 +29,14 @@ class SqliteWrapper(object):
         cursor.execute(statement, args)
         return self._connection, cursor
 
+    def get_value(self, statement, *args):
+        con, cur = self.execute(statement, *args)
+        try:
+            return cur.fetchone()[0]
+        except Exception, ex:
+            print "ERROR:", type(ex), ex
+            return None
+
     def get(self, statement, *args):
         con, cur = self.execute(statement, *args)
         return cur.fetchone()
@@ -168,15 +176,15 @@ class WebHook(object):
 
     def push(self):
         repository_url = self.get_repository_url()
-        repository_id = self.application.db.get("SELECT id FROM repository WHERE url = ?", repository_url)
+        repository_id = self.application.db.get_value("SELECT id FROM repository WHERE url = ?", repository_url)
         if not repository_id:
             repository_url, repository_owner, repository_name = self.get_repository()
             repository_id = self.application.db.new("INSERT INTO repository VALUES (NULL, ?, ?, ?, DATETIME('NOW'))",
                                                     repository_url, repository_owner, repository_name)
 
         branch = self.get_branch()
-        branch_id = self.application.db.get("SELECT id FROM branch WHERE repository = ? AND name = ?",
-                                            repository_id, branch)
+        branch_id = self.application.db.get_value("SELECT id FROM branch WHERE repository = ? AND name = ?",
+                                                  repository_id, branch)
         if not branch_id:
             branch_id = self.application.db.new("INSERT INTO branch VALUES (NULL, ?, ?, NULL, NULL, NULL)",
                                                 branch, repository_id)
